==> jc-1.4.0.tar.gz: java/awt/Robot__241.h <==
// final class java.awt.Robot$1

// class file dependencies
// @dep_class 4792c7d6327892b9 java_awt_Robot__241
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Robot__241_H_
#define _JC_java_awt_Robot__241_H_

// Forward structure declarations
struct _jc_java_awt_Robot$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Robot__241$sub_refs	_jc_java_awt_Robot__241$sub_refs;
typedef struct _jc_java_awt_Robot__241$sub_nonrefs	_jc_java_awt_Robot__241$sub_nonrefs;
typedef struct _jc_java_awt_Robot__241$refs	_jc_java_awt_Robot__241$refs;
typedef struct _jc_java_awt_Robot__241$nonrefs	_jc_java_awt_Robot__241$nonrefs;
typedef struct _jc_java_awt_Robot__241$object	_jc_java_awt_Robot__241$object;

typedef const struct _jc_java_awt_Robot__241$vmethods	_jc_java_awt_Robot__241$vmethods;
typedef const struct _jc_java_awt_Robot__241$vtable	_jc_java_awt_Robot__241$vtable;
typedef const struct _jc_java_awt_Robot__241$vtype	_jc_java_awt_Robot__241$vtype;

// Constructors
extern void _jc_java_awt_Robot__241$method$_init$1249e83ab043baf1(_jc_env *, struct _jc_java_awt_Robot__241$object *, struct _jc_java_awt_Robot$object *);

// Virtual methods
extern void _jc_java_awt_Robot__241$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_awt_Robot__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Robot__241$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_java_awt_Robot__241$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_awt_Robot__241$object *);
};

// Vtable
struct _jc_java_awt_Robot__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Robot__241$vmethods	java_awt_Robot__241;
};

// Vtype
struct _jc_java_awt_Robot__241$vtype {
	_jc_type			type;
	_jc_java_awt_Robot__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Robot__241$sub_refs {
	struct _jc_java_awt_Robot$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Robot__241$refs {
    _jc_java_awt_Robot__241$sub_refs	java_awt_Robot__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Robot__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Robot__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Robot__241$sub_nonrefs	java_awt_Robot__241;
};

// Object instance structure
struct _jc_java_awt_Robot__241$object {
	_jc_java_awt_Robot__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Robot__241$vtype	*vtype;
	_jc_java_awt_Robot__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Robot__241$vtype _jc_java_awt_Robot__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Robot__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Robot__241$class_object;

#endif	/* _JC_java_awt_Robot__241_H_ */

==> jc-1.4.5.tar.gz: java/awt/Robot__241.h <==
// final class java.awt.Robot$1

// class file dependencies
// @dep_class f36ea2dcfb02579b java_awt_Robot__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Robot__241_H_
#define _JC_java_awt_Robot__241_H_

// Forward structure declarations
struct _jc_java_awt_Robot$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Robot__241$sub_refs	_jc_java_awt_Robot__241$sub_refs;
typedef struct _jc_java_awt_Robot__241$sub_nonrefs	_jc_java_awt_Robot__241$sub_nonrefs;
typedef struct _jc_java_awt_Robot__241$refs	_jc_java_awt_Robot__241$refs;
typedef struct _jc_java_awt_Robot__241$nonrefs	_jc_java_awt_Robot__241$nonrefs;
typedef struct _jc_java_awt_Robot__241$object	_jc_java_awt_Robot__241$object;

typedef const struct _jc_java_awt_Robot__241$vmethods	_jc_java_awt_Robot__241$vmethods;
typedef const struct _jc_java_awt_Robot__241$vtable	_jc_java_awt_Robot__241$vtable;
typedef const struct _jc_java_awt_Robot__241$vtype	_jc_java_awt_Robot__241$vtype;

// Constructors
extern void _jc_java_awt_Robot__241$method$_init$1249e83ab043baf1(_jc_env *, struct _jc_java_awt_Robot__241$object *, struct _jc_java_awt_Robot$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Robot__241$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_awt_Robot__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Robot__241$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_java_awt_Robot__241$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_awt_Robot__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Robot__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Robot__241$vmethods	java_awt_Robot__241;
};

// Vtype
struct _jc_java_awt_Robot__241$vtype {
	_jc_type			type;
	_jc_java_awt_Robot__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Robot__241$sub_refs {
	struct _jc_java_awt_Robot$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Robot__241$refs {
    _jc_java_awt_Robot__241$sub_refs	java_awt_Robot__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Robot__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Robot__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Robot__241$sub_nonrefs	java_awt_Robot__241;
};

// Object instance structure
struct _jc_java_awt_Robot__241$object {
	_jc_java_awt_Robot__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Robot__241$vtype	*vtype;
	_jc_java_awt_Robot__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Robot__241$vtype _jc_java_awt_Robot__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Robot__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Robot__241$class_object;

#endif	/* _JC_java_awt_Robot__241_H_ */
